@@ -49,12 +49,12 @@
 
 #define E_DATA_BOOK_FACTORY_SERVICE_NAME "org.gnome.evolution.dataserver.AddressBook"
 
-static gchar ** flatten_stringlist(GList *list);
+static gchar ** flatten_stringlist (GList *list);
 static GList *array_to_stringlist (gchar **list);
 static EList *array_to_elist (gchar **list);
 static gboolean unwrap_gerror (GError *error, GError **client_error);
 
-G_DEFINE_TYPE(EBook, e_book, G_TYPE_OBJECT)
+G_DEFINE_TYPE (EBook, e_book, G_TYPE_OBJECT)
 #define E_BOOK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), E_TYPE_BOOK, EBookPrivate))
 
 enum {
@@ -1238,7 +1238,7 @@ e_book_authenticate_user_async (EBook              *book,
  * e_book_get_contact:
  * @book: an #EBook
  * @id: a unique string ID specifying the contact
- * @contact: (out) (transfer: full): an #EContact
+ * @contact: an #EContact
  * @error: a #GError to set on failure
  *
  * Fills in @contact with the contents of the vcard in @book
@@ -1892,7 +1892,7 @@ get_book_view_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
  * @query: an #EBookQuery
  * @requested_fields: a #GList containing the names of fields to return, or NULL for all
  * @max_results: the maximum number of contacts to show (or 0 for all)
- * @cb: (scope call): a function to call when the operation finishes
+ * @cb: a function to call when the operation finishes
  * @closure: data to pass to callback function
  *
  * Query @book with @query, creating a #EBookView with the fields
@@ -1937,7 +1937,7 @@ e_book_async_get_book_view (EBook                 *book,
  * @query: an #EBookQuery
  * @requested_fields: a #GList containing the names of fields to return, or NULL for all
  * @max_results: the maximum number of contacts to show (or 0 for all)
- * @cb: (scope call): a function to call when the operation finishes
+ * @cb: a function to call when the operation finishes
  * @closure: data to pass to callback function
  *
  * Query @book with @query, creating a #EBookView with the fields
@@ -2454,7 +2454,7 @@ open_reply (GObject *gdbus_book, GAsyncResult *res, gpointer user_data)
  * e_book_async_open:
  * @book: an #EBook
  * @only_if_exists: if %TRUE, fail if this book doesn't already exist, otherwise create it first
- * @open_response: (scope call) (closure closure): a function to call when the operation finishes
+ * @open_response: a function to call when the operation finishes
  * @closure: data to pass to callback function
  *
  * Opens the addressbook, making it ready for queries and other operations.
@@ -2490,7 +2490,7 @@ e_book_async_open (EBook                 *book,
  * e_book_open_async:
  * @book: an #EBook
  * @only_if_exists: if %TRUE, fail if this book doesn't already exist, otherwise create it first
- * @open_response: (scope call): a function to call when the operation finishes
+ * @open_response: a function to call when the operation finishes
  * @closure: data to pass to callback function
  *
  * Opens the addressbook, making it ready for queries and other operations.
@@ -2854,7 +2854,7 @@ e_book_get_self (EContact **contact, EBook **book, GError **error)
 		return FALSE;
 	}
 
-	gconf = gconf_client_get_default();
+	gconf = gconf_client_get_default ();
 	uid = gconf_client_get_string (gconf, SELF_UID_KEY, NULL);
 	g_object_unref (gconf);
 
@@ -2904,7 +2904,7 @@ e_book_set_self (EBook *book, EContact *contact, GError **error)
 	e_return_error_if_fail (E_IS_BOOK (book), E_BOOK_ERROR_INVALID_ARG);
 	e_return_error_if_fail (E_IS_CONTACT (contact), E_BOOK_ERROR_INVALID_ARG);
 
-	gconf = gconf_client_get_default();
+	gconf = gconf_client_get_default ();
 	gconf_client_set_string (gconf, SELF_UID_KEY, e_contact_get_const (contact, E_CONTACT_UID), NULL);
 	g_object_unref (gconf);
 
@@ -2930,7 +2930,7 @@ e_book_is_self (EContact *contact)
 	   need a GError** arg for that */
 	g_return_val_if_fail (contact && E_IS_CONTACT (contact), FALSE);
 
-	gconf = gconf_client_get_default();
+	gconf = gconf_client_get_default ();
 	uid = gconf_client_get_string (gconf, SELF_UID_KEY, NULL);
 	g_object_unref (gconf);
 
@@ -3031,7 +3031,7 @@ e_book_set_default_source (ESource *source, GError **error)
 
 /**
  * e_book_get_addressbooks:
- * @addressbook_sources: (out): A pointer to a #ESourceList* to set
+ * @addressbook_sources: A pointer to a ESourceList* to set
  * @error: A pointer to a GError* to set on error
  *
  * Populate *addressbook_sources with the list of all sources which have been
@@ -3046,7 +3046,7 @@ e_book_get_addressbooks (ESourceList **addressbook_sources, GError **error)
 
 	e_return_error_if_fail (addressbook_sources, E_BOOK_ERROR_INVALID_ARG);
 
-	gconf = gconf_client_get_default();
+	gconf = gconf_client_get_default ();
 	*addressbook_sources = e_source_list_new_for_gconf (gconf, "/apps/evolution/addressbook/sources");
 	g_object_unref (gconf);
 
@@ -3349,12 +3349,7 @@ e_book_new_default_addressbook (GError **error)
 		return NULL;
 
 	source = e_source_list_peek_default_source (source_list);
-	if (!source) {
-		g_set_error_literal (error, E_BOOK_ERROR, E_BOOK_ERROR_NO_SUCH_BOOK,
-			     _("Address book does not exist"));
-		g_object_unref (source_list);
-		return NULL;
-	}
+	g_return_val_if_fail (source != NULL, NULL);
 
 	book = e_book_new (source, error);
 
@@ -3488,7 +3483,7 @@ array_to_stringlist (gchar **list)
 	while (*i != NULL) {
 		l = g_list_prepend (l, g_strdup (*i++));
 	}
-	return g_list_reverse(l);
+	return g_list_reverse (l);
 }
 
 static EList *
