@@ -146,12 +146,12 @@ camel_file_util_decode_fixed_int32 (FILE *in, gint32 *dest)
 
 #define CFU_ENCODE_T(type)						\
 gint									\
-camel_file_util_encode_##type(FILE *out, type value)			\
+camel_file_util_encode_##type (FILE *out, type value)			\
 {									\
 	gint i;								\
 									\
 	for (i = sizeof (type) - 1; i >= 0; i--) {			\
-		if (fputc((value >> (i * 8)) & 0xff, out) == -1)	\
+		if (fputc ((value >> (i * 8)) & 0xff, out) == -1)	\
 			return -1;					\
 	}								\
 	return 0;							\
@@ -159,10 +159,10 @@ camel_file_util_encode_##type(FILE *out, type value)			\
 
 #define CFU_DECODE_T(type)				\
 gint							\
-camel_file_util_decode_##type(FILE *in, type *dest)	\
+camel_file_util_decode_##type (FILE *in, type *dest)	\
 {							\
 	type save = 0;					\
-	gint i = sizeof(type) - 1;			\
+	gint i = sizeof (type) - 1;			\
 	gint v = EOF;					\
 							\
         while (i >= 0 && (v = fgetc (in)) != EOF) {	\
@@ -184,7 +184,7 @@ camel_file_util_decode_##type(FILE *in, type *dest)	\
  *
  * Returns: %0 on success, %-1 on error.
  **/
-CFU_ENCODE_T(time_t)
+CFU_ENCODE_T (time_t)
 
 /**
  * camel_file_util_decode_time_t:
@@ -195,7 +195,7 @@ CFU_ENCODE_T(time_t)
  *
  * Returns: %0 on success, %-1 on error.
  **/
-CFU_DECODE_T(time_t)
+CFU_DECODE_T (time_t)
 
 /**
  * camel_file_util_encode_off_t:
@@ -206,7 +206,7 @@ CFU_DECODE_T(time_t)
  *
  * Returns: %0 on success, %-1 on error.
  **/
-CFU_ENCODE_T(off_t)
+CFU_ENCODE_T (off_t)
 
 /**
  * camel_file_util_decode_off_t:
@@ -217,7 +217,7 @@ CFU_ENCODE_T(off_t)
  *
  * Returns: %0 on success, %-1 on failure.
  **/
-CFU_DECODE_T(off_t)
+CFU_DECODE_T (off_t)
 
 /**
  * camel_file_util_encode_gsize:
@@ -228,7 +228,7 @@ CFU_DECODE_T(off_t)
  *
  * Returns: %0 on success, %-1 on error.
  **/
-CFU_ENCODE_T(gsize)
+CFU_ENCODE_T (gsize)
 
 /**
  * camel_file_util_decode_gsize:
@@ -239,7 +239,7 @@ CFU_ENCODE_T(gsize)
  *
  * Returns: %0 on success, %-1 on failure.
  **/
-CFU_DECODE_T(gsize)
+CFU_DECODE_T (gsize)
 
 /**
  * camel_file_util_encode_string:
@@ -331,8 +331,8 @@ camel_file_util_encode_fixed_string (FILE *out, const gchar *str, gsize len)
 	if (len > 65536)
 		len = 65536;
 
-	memset(buf, 0x00, len);
-	g_strlcpy(buf, str, len);
+	memset (buf, 0x00, len);
+	g_strlcpy (buf, str, len);
 
 	if (fwrite (buf, len, 1, out) == len)
 		return 0;
@@ -393,7 +393,7 @@ camel_file_util_safe_filename (const gchar *name)
 	if (name == NULL)
 		return NULL;
 
-	return camel_url_encode(name, unsafe_chars);
+	return camel_url_encode (name, unsafe_chars);
 }
 
 /* FIXME: poll() might be more efficient and more portable? */
@@ -403,6 +403,7 @@ camel_file_util_safe_filename (const gchar *name)
  * @fd: file descriptor
  * @buf: buffer to fill
  * @n: number of bytes to read into @buf
+ * @cancellable: optional #GCancellable object, or %NULL
  * @error: return location for a #GError, or %NULL
  *
  * Cancellable libc read() replacement.
@@ -417,25 +418,19 @@ gssize
 camel_read (gint fd,
             gchar *buf,
             gsize n,
+            GCancellable *cancellable,
             GError **error)
 {
 	gssize nread;
 	gint cancel_fd;
 
-	if (camel_operation_cancel_check (NULL)) {
+	if (g_cancellable_set_error_if_cancelled (cancellable, error)) {
 		errno = EINTR;
-		g_set_error (
-			error, G_IO_ERROR,
-			G_IO_ERROR_CANCELLED,
-			_("Cancelled"));
 		return -1;
 	}
 
-#ifndef G_OS_WIN32
-	cancel_fd = camel_operation_cancel_fd (NULL);
-#else
-	cancel_fd = -1;
-#endif
+	cancel_fd = g_cancellable_get_fd (cancellable);
+
 	if (cancel_fd == -1) {
 		do {
 			nread = read (fd, buf, n);
@@ -460,7 +455,7 @@ camel_read (gint fd,
 			tv.tv_usec = 0;
 			nread = -1;
 
-			res = select(fdmax, &rdset, 0, 0, &tv);
+			res = select (fdmax, &rdset, 0, 0, &tv);
 			if (res == -1)
 				;
 			else if (res == 0)
@@ -481,18 +476,16 @@ camel_read (gint fd,
 #endif
 	}
 
-	if (nread == -1) {
-		if (errno == EINTR)
-			g_set_error (
-				error, G_IO_ERROR,
-				G_IO_ERROR_CANCELLED,
-				_("Cancelled"));
-		else
-			g_set_error (
-				error, G_IO_ERROR,
-				g_io_error_from_errno (errno),
-				"%s", g_strerror (errno));
-	}
+	g_cancellable_release_fd (cancellable);
+
+	if (g_cancellable_set_error_if_cancelled (cancellable, error))
+		return -1;
+
+	if (nread == -1)
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			"%s", g_strerror (errno));
 
 	return nread;
 }
@@ -502,6 +495,7 @@ camel_read (gint fd,
  * @fd: file descriptor
  * @buf: buffer to write
  * @n: number of bytes of @buf to write
+ * @cancellable: optional #GCancellable object, or %NULL
  * @error: return location for a #GError, or %NULL
  *
  * Cancellable libc write() replacement.
@@ -516,25 +510,19 @@ gssize
 camel_write (gint fd,
              const gchar *buf,
              gsize n,
+             GCancellable *cancellable,
              GError **error)
 {
 	gssize w, written = 0;
 	gint cancel_fd;
 
-	if (camel_operation_cancel_check (NULL)) {
+	if (g_cancellable_set_error_if_cancelled (cancellable, error)) {
 		errno = EINTR;
-		g_set_error (
-			error, G_IO_ERROR,
-			G_IO_ERROR_CANCELLED,
-			_("Cancelled"));
 		return -1;
 	}
 
-#ifndef G_OS_WIN32
-	cancel_fd = camel_operation_cancel_fd (NULL);
-#else
-	cancel_fd = -1;
-#endif
+	cancel_fd = g_cancellable_get_fd (cancellable);
+
 	if (cancel_fd == -1) {
 		do {
 			do {
@@ -591,17 +579,16 @@ camel_write (gint fd,
 #endif
 	}
 
+	g_cancellable_release_fd (cancellable);
+
+	if (g_cancellable_set_error_if_cancelled (cancellable, error))
+		return -1;
+
 	if (w == -1) {
-		if (errno == EINTR)
-			g_set_error (
-				error, G_IO_ERROR,
-				G_IO_ERROR_CANCELLED,
-				_("Cancelled"));
-		else
-			g_set_error (
-				error, G_IO_ERROR,
-				g_io_error_from_errno (errno),
-				"%s", g_strerror (errno));
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			"%s", g_strerror (errno));
 		return -1;
 	}
 
@@ -613,6 +600,7 @@ camel_write (gint fd,
  * @fd: a socket
  * @buf: buffer to fill
  * @n: number of bytes to read into @buf
+ * @cancellable: optional #GCancellable object, or %NULL
  * @error: return location for a #GError, or %NULL
  *
  * Cancellable read() replacement for sockets. Code that intends to be
@@ -627,23 +615,21 @@ gssize
 camel_read_socket (gint fd,
                    gchar *buf,
                    gsize n,
+                   GCancellable *cancellable,
                    GError **error)
 {
 #ifndef G_OS_WIN32
-	return camel_read (fd, buf, n, error);
+	return camel_read (fd, buf, n, cancellable, error);
 #else
 	gssize nread;
 	gint cancel_fd;
 
-	if (camel_operation_cancel_check (NULL)) {
+	if (g_cancellable_set_error_if_cancelled (cancellable, error)) {
 		errno = EINTR;
-		g_set_error (
-			error, G_IO_ERROR,
-			G_IO_ERROR_CANCELLED,
-			_("Canceled"));
 		return -1;
 	}
-	cancel_fd = camel_operation_cancel_fd (NULL);
+
+	cancel_fd = g_cancellable_get_fd (cancellable);
 
 	if (cancel_fd == -1) {
 		do {
@@ -667,7 +653,7 @@ camel_read_socket (gint fd,
 			tv.tv_usec = 0;
 			nread = -1;
 
-			res = select(fdmax, &rdset, 0, 0, &tv);
+			res = select (fdmax, &rdset, 0, 0, &tv);
 			if (res == -1)
 				;
 			else if (res == 0)
@@ -683,18 +669,16 @@ camel_read_socket (gint fd,
 		;
 	}
 
-	if (nread == -1) {
-		if (errno == EINTR)
-			g_set_error (
-				error, G_IO_ERROR,
-				G_IO_ERROR_CANCELLED,
-				_("Cancelled"));
-		else
-			g_set_error (
-				error, G_IO_ERROR,
-				g_io_error_from_errno (errno),
-				"%s", g_strerror (errno));
-	}
+	g_cancellable_release_fd (cancellable);
+
+	if (g_cancellable_set_error_if_cancelled (cancellable, error))
+		return -1;
+
+	if (nread == -1)
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			"%s", g_strerror (errno));
 
 	return nread;
 #endif
@@ -718,15 +702,16 @@ gssize
 camel_write_socket (gint fd,
                     const gchar *buf,
                     gsize n,
+                    GCancellable *cancellable,
                     GError **error)
 {
 #ifndef G_OS_WIN32
-	return camel_write (fd, buf, n, error);
+	return camel_write (fd, buf, n, cancellable, error);
 #else
 	gssize w, written = 0;
 	gint cancel_fd;
 
-	if (camel_operation_cancel_check (NULL)) {
+	if (g_cancellable_is_cancelled (cancellable)) {
 		errno = EINTR;
 		g_set_error (
 			error, G_IO_ERROR,
@@ -735,7 +720,8 @@ camel_write_socket (gint fd,
 		return -1;
 	}
 
-	cancel_fd = camel_operation_cancel_fd (NULL);
+	cancel_fd = g_cancellable_get_fd (cancellable);
+
 	if (cancel_fd == -1) {
 		do {
 			do {
@@ -783,17 +769,16 @@ camel_write_socket (gint fd,
 		ioctlsocket (fd, FIONBIO, &arg);
 	}
 
+	g_cancellable_release_fd (cancellable);
+
+	if (g_cancellable_set_error_if_cancelled (cancellable, error))
+		return -1;
+
 	if (w == -1) {
-		if (errno == EINTR)
-			g_set_error (
-				error, G_IO_ERROR,
-				G_IO_ERROR_CANCELLED,
-				_("Canceled"));
-		else
-			g_set_error (
-				error, G_IO_ERROR,
-				g_io_error_from_errno (errno),
-				"%s", g_strerror (errno));
+		g_set_error (
+			error, G_IO_ERROR,
+			g_io_error_from_errno (errno),
+			"%s", g_strerror (errno));
 		return -1;
 	}
 
@@ -812,16 +797,16 @@ camel_write_socket (gint fd,
  * Returns: The new pathname.  It must be free'd with g_free().
  **/
 gchar *
-camel_file_util_savename(const gchar *filename)
+camel_file_util_savename (const gchar *filename)
 {
 	gchar *dirname, *retval;
 
-	dirname = g_path_get_dirname(filename);
+	dirname = g_path_get_dirname (filename);
 
 	if (strcmp (dirname, ".") == 0) {
 		retval = g_strconcat (".#", filename, NULL);
 	} else {
-		gchar *basename = g_path_get_basename(filename);
+		gchar *basename = g_path_get_basename (filename);
 		gchar *newbasename = g_strconcat (".#", basename, NULL);
 
 		retval = g_build_filename (dirname, newbasename, NULL);
